/* gtkentrymask - gtkentry with type, mask and i18n
 * Copyright (C) 2001 Santiago Capel
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

#ifndef __GTKX_ENTRYMASK_H__
#define __GTKX_ENTRYMASK_H__


#include <gdk/gdk.h>
#include <gtk/gtkentry.h>


#ifdef __cplusplus
extern "C" {
#endif /* __cplusplus */


#define GTKX_TYPE_ENTRYMASK              (gtkx_entrymask_get_type ())
#define GTKX_ENTRYMASK(obj)              (GTK_CHECK_CAST ((obj), GTKX_TYPE_ENTRYMASK, GtkxEntryMask))
#define GTKX_ENTRYMASK_CLASS(klass)      (GTK_CHECK_CLASS_CAST ((klass), GTKX_TYPE_ENTRYMASK, GtkxEntryMaskClass))
#define GTKX_IS_ENTRYMASK(obj)               (GTK_CHECK_TYPE ((obj), GTKX_TYPE_ENTRYMASK))
#define GTKX_IS_ENTRYMASK_CLASS(klass)       (GTKX_CHECK_CLASS_TYPE ((klass), GTKX_TYPE_ENTRYMASK))


/*
typedef enum _GtkxEntryMaskType {
  ENTRYMASK_STRING,
  ENTRYMASK_NUMBER,
  ENTRYMASK_DATE,
  ENTRYMASK_TIME
} GtkxEntryMaskType;
*/

typedef int GtkxEntryMaskType;
#define ENTRYMASK_STRING          0
#define ENTRYMASK_NUMERIC         1
#define ENTRYMASK_CURRENCY        2
#define ENTRYMASK_DATE            3
#define ENTRYMASK_TIME            4
#define ENTRYMASK_DATETIME        5


typedef struct _GtkxEntryMask       GtkxEntryMask;
typedef struct _GtkxEntryMaskClass  GtkxEntryMaskClass;

struct _GtkxEntryMask
{
  GtkEntry entry;

  GtkxEntryMaskType valuetype;
  const gchar *mask;
  const gchar *format;
  gchar blank_char;
  gint8 formating;
  gint8 masking;
  gint8 forced;
};

struct _GtkxEntryMaskClass
{
  GtkEntryClass parent_class;
};


GtkType          gtkx_entrymask_get_type   	(void);
GtkWidget*       gtkx_entrymask_new    		(void);
GtkWidget*       gtkx_entrymask_new_with_type    (GtkxEntryMaskType type,
						 const gchar *format,
						 const gchar *mask);
void             gtkx_entrymask_set_text      	(GtkxEntryMask  *entrymask,
						 const gchar   *text);
void             gtkx_entrymask_set_text_forced (GtkxEntryMask *entrymask,
						 const gchar *text);
/* returns a reference to the text */
gchar*           gtkx_entrymask_get_text      	(GtkxEntryMask  *entrymask);
void             gtkx_entrymask_set_position     (GtkxEntryMask  *entrymask,
						 gint           position);
void             gtkx_entrymask_set_visibility 	(GtkxEntryMask   *entrymask,
						 gboolean       visible);
void             gtkx_entrymask_set_editable   	(GtkxEntryMask   *entrymask,
						 gboolean       editable);
/* text is truncated if needed */
void             gtkx_entrymask_set_max_length 	(GtkxEntryMask   *entrymask,
						 guint16        max);
void             gtkx_entrymask_set_valuetype 	(GtkxEntryMask   *entrymask,
						 GtkxEntryMaskType type);
void             gtkx_entrymask_set_mask        (GtkxEntryMask   *entrymask,
						 const gchar *mask);
void             gtkx_entrymask_set_format      (GtkxEntryMask   *entrymask,
						 const gchar *format);
GtkxEntryMaskType gtkx_entrymask_get_valuetype   (GtkxEntryMask   *entrymask);
const gchar *    gtkx_entrymask_get_format       (GtkxEntryMask   *entrymask);
const gchar *    gtkx_entrymask_get_mask         (GtkxEntryMask   *entrymask);
guint16          gtkx_entrymask_get_max_length   (GtkxEntryMask   *entrymask);

void             gtkx_entrymask_set_blank_char   (GtkxEntryMask *entrymask,
						 const gchar blank_char);
gchar            gtkx_entrymask_get_blank_char   (GtkxEntryMask *entrymask);
void             gtkx_entrymask_set_integer      (GtkxEntryMask *entrymask, 
						 gint val);
gint             gtkx_entrymask_get_integer      (GtkxEntryMask *entrymask);
void             gtkx_entrymask_set_double       (GtkxEntryMask *entrymask, 
						 gdouble val);
gdouble          gtkx_entrymask_get_double       (GtkxEntryMask *entrymask);
void             gtkx_entrymask_set_time_t       (GtkxEntryMask *entrymask, 
						  time_t adate);
time_t           gtkx_entrymask_get_time_t       (GtkxEntryMask *entrymask);


#ifdef __cplusplus
}
#endif /* __cplusplus */


#endif /* __GTKX_ENTRYMASK_H__ */









