# Configure paths for GTK+WIDGEXTS
# Owen Taylor     97-11-3
# Adrian Feiguin  01-04-03 

dnl AM_PATH_GTK_WIDGEXTS([MINIMUM-VERSION, [ACTION-IF-FOUND [, ACTION-IF-NOT-FOUND [, MODULES]]]])
dnl Test for GTK_WIDGEXTS, and define GTK_WIDGEXTS_CFLAGS and GTK_WIDGEXTS_LIBS
dnl
AC_DEFUN(AM_PATH_GTK_WIDGEXTS,
[dnl 
dnl Get the cflags and libraries from the gtkwidgexts-config script
dnl
AC_ARG_WITH(gtkwidgexts-prefix,[  --with-gtkwidgexts-prefix=PFX   Prefix where GTK_WIDGEXTS is installed (optional)],
            gtkwidgexts_config_prefix="$withval", gtkwidgexts_config_prefix="")
AC_ARG_WITH(gtkwidgexts-exec-prefix,[  --with-gtkwidgexts-exec-prefix=PFX Exec prefix where GTK_WIDGEXTS is installed (optional)],
            gtkwidgexts_config_exec_prefix="$withval", gtkwidgexts_config_exec_prefix="")
AC_ARG_ENABLE(gtkwidgextstest, [  --disable-gtkwidgextstest       Do not try to compile and run a test GTK_WIDGEXTS program],
		    , enable_gtkwidgextstest=yes)

  for module in . $4
  do
      case "$module" in
         gthread) 
             gtkwidgexts_config_args="$gtkwidgexts_config_args gthread"
         ;;
      esac
  done

  if test x$gtkwidgexts_config_exec_prefix != x ; then
     gtkwidgexts_config_args="$gtkwidgexts_config_args --exec-prefix=$gtkwidgexts_config_exec_prefix"
     if test x${GTK_WIDGEXTS_CONFIG+set} != xset ; then
        GTK_WIDGEXTS_CONFIG=$gtkwidgexts_config_exec_prefix/bin/gtkwidgexts-config
     fi
  fi
  if test x$gtkwidgexts_config_prefix != x ; then
     gtkwidgexts_config_args="$gtkwidgexts_config_args --prefix=$gtkwidgexts_config_prefix"
     if test x${GTK_WIDGEXTS_CONFIG+set} != xset ; then
        GTK_WIDGEXTS_CONFIG=$gtkwidgexts_config_prefix/bin/gtkwidgexts-config
     fi
  fi

  AC_PATH_PROG(GTK_WIDGEXTS_CONFIG, gtkwidgexts-config, no)
  min_gtkwidgexts_version=ifelse([$1], ,0.99.13,$1)
  AC_MSG_CHECKING(for GTK_WIDGEXTS - version >= $min_gtkwidgexts_version)
  no_gtkwidgexts=""
  if test "$GTK_WIDGEXTS_CONFIG" = "no" ; then
    no_gtkwidgexts=yes
  else
    GTK_WIDGEXTS_CFLAGS=`$GTK_WIDGEXTS_CONFIG $gtkwidgexts_config_args --cflags`
    GTK_WIDGEXTS_LIBS=`$GTK_WIDGEXTS_CONFIG $gtkwidgexts_config_args --libs`
    gtkwidgexts_config_major_version=`$GTK_WIDGEXTS_CONFIG $gtkwidgexts_config_args --version | \
           sed 's/\([[0-9]]*\).\([[0-9]]*\).\([[0-9]]*\)/\1/'`
    gtkwidgexts_config_minor_version=`$GTK_WIDGEXTS_CONFIG $gtkwidgexts_config_args --version | \
           sed 's/\([[0-9]]*\).\([[0-9]]*\).\([[0-9]]*\)/\2/'`
    gtkwidgexts_config_micro_version=`$GTK_WIDGEXTS_CONFIG $gtkwidgexts_config_args --version | \
           sed 's/\([[0-9]]*\).\([[0-9]]*\).\([[0-9]]*\)/\3/'`
    if test "x$enable_gtkwidgextstest" = "xyes" ; then
      ac_save_CFLAGS="$CFLAGS"
      ac_save_LIBS="$LIBS"
      CFLAGS="$CFLAGS $GTK_WIDGEXTS_CFLAGS"
      LIBS="$GTK_WIDGEXTS_LIBS $LIBS"
dnl
dnl Now check if the installed GTK_WIDGEXTS is sufficiently new. (Also sanity
dnl checks the results of gtkwidgexts-config to some extent
dnl
      rm -f conf.gtkwidgextstest
      AC_TRY_RUN([
#include <gtkwidgexts/gtkwidgexts.h>
#include <stdio.h>
#include <stdlib.h>

int 
main ()
{
  int major, minor, micro;
  char *tmp_version;

  system ("touch conf.gtkwidgextstest");

  /* HP/UX 9 (%@#!) writes to sscanf strings */
  tmp_version = g_strdup("$min_gtkwidgexts_version");
  if (sscanf(tmp_version, "%d.%d.%d", &major, &minor, &micro) != 3) {
     printf("%s, bad version string\n", "$min_gtkwidgexts_version");
     exit(1);
   }

  if ((gtkwidgexts_major_version != $gtkwidgexts_config_major_version) ||
      (gtkwidgexts_minor_version != $gtkwidgexts_config_minor_version) ||
      (gtkwidgexts_micro_version != $gtkwidgexts_config_micro_version))
    {
      printf("\n*** 'gtkwidgexts-config --version' returned %d.%d.%d, but GTK_WIDGEXTS+ (%d.%d.%d)\n", 
             $gtkwidgexts_config_major_version, $gtkwidgexts_config_minor_version, $gtkwidgexts_config_micro_version,
             gtkwidgexts_major_version, gtkwidgexts_minor_version, gtkwidgexts_micro_version);
      printf ("*** was found! If gtkwidgexts-config was correct, then it is best\n");
      printf ("*** to remove the old version of GTK_WIDGEXTS+. You may also be able to fix the error\n");
      printf("*** by modifying your LD_LIBRARY_PATH enviroment variable, or by editing\n");
      printf("*** /etc/ld.so.conf. Make sure you have run ldconfig if that is\n");
      printf("*** required on your system.\n");
      printf("*** If gtkwidgexts-config was wrong, set the environment variable GTK_WIDGEXTS_CONFIG\n");
      printf("*** to point to the correct copy of gtkwidgexts-config, and remove the file config.cache\n");
      printf("*** before re-running configure\n");
    } 
#if defined (GTK_WIDGEXTS_MAJOR_VERSION) && defined (GTK_WIDGEXTS_MINOR_VERSION) && defined (GTK_WIDGEXTS_MICRO_VERSION)
  else if ((gtkwidgexts_major_version != GTK_WIDGEXTS_MAJOR_VERSION) ||
	   (gtkwidgexts_minor_version != GTK_WIDGEXTS_MINOR_VERSION) ||
           (gtkwidgexts_micro_version != GTK_WIDGEXTS_MICRO_VERSION))
    {
      printf("*** GTK_WIDGEXTS+ header files (version %d.%d.%d) do not match\n",
	     GTK_WIDGEXTS_MAJOR_VERSION, GTK_WIDGEXTS_MINOR_VERSION, GTK_WIDGEXTS_MICRO_VERSION);
      printf("*** library (version %d.%d.%d)\n",
	     gtkwidgexts_major_version, gtkwidgexts_minor_version, gtkwidgexts_micro_version);
    }
#endif /* defined (GTK_WIDGEXTS_MAJOR_VERSION) ... */
  else
    {
      if ((gtkwidgexts_major_version > major) ||
        ((gtkwidgexts_major_version == major) && (gtkwidgexts_minor_version > minor)) ||
        ((gtkwidgexts_major_version == major) && (gtkwidgexts_minor_version == minor) && (gtkwidgexts_micro_version >= micro)))
      {
        return 0;
       }
     else
      {
        printf("\n*** An old version of GTK_WIDGEXTS+ (%d.%d.%d) was found.\n",
               gtkwidgexts_major_version, gtkwidgexts_minor_version, gtkwidgexts_micro_version);
        printf("*** You need a version of GTK_WIDGEXTS+ newer than %d.%d.%d. The latest version of\n",
	       major, minor, micro);
        printf("*** GTK_WIDGEXTS+ is always available from ftp://ftp.gtkwidgexts.org.\n");
        printf("***\n");
        printf("*** If you have already installed a sufficiently new version, this error\n");
        printf("*** probably means that the wrong copy of the gtkwidgexts-config shell script is\n");
        printf("*** being found. The easiest way to fix this is to remove the old version\n");
        printf("*** of GTK_WIDGEXTS+, but you can also set the GTK_WIDGEXTS_CONFIG environment to point to the\n");
        printf("*** correct copy of gtkwidgexts-config. (In this case, you will have to\n");
        printf("*** modify your LD_LIBRARY_PATH enviroment variable, or edit /etc/ld.so.conf\n");
        printf("*** so that the correct libraries are found at run-time))\n");
      }
    }
  return 1;
}
],, no_gtkwidgexts=yes,[echo $ac_n "cross compiling; assumed OK... $ac_c"])
       CFLAGS="$ac_save_CFLAGS"
       LIBS="$ac_save_LIBS"
     fi
  fi
  if test "x$no_gtkwidgexts" = x ; then
     AC_MSG_RESULT(yes)
     ifelse([$2], , :, [$2])     
  else
     AC_MSG_RESULT(no)
     if test "$GTK_WIDGEXTS_CONFIG" = "no" ; then
       echo "*** The gtkwidgexts-config script installed by GTK_WIDGEXTS could not be found"
       echo "*** If GTK_WIDGEXTS was installed in PREFIX, make sure PREFIX/bin is in"
       echo "*** your path, or set the GTK_WIDGEXTS_CONFIG environment variable to the"
       echo "*** full path to gtkwidgexts-config."
     else
       if test -f conf.gtkwidgextstest ; then
        :
       else
          echo "*** Could not run GTK_WIDGEXTS test program, checking why..."
          CFLAGS="$CFLAGS $GTK_WIDGEXTS_CFLAGS"
          LIBS="$LIBS $GTK_WIDGEXTS_LIBS"
          AC_TRY_LINK([
#include <gtkwidgexts/gtkwidgexts.h>
#include <stdio.h>
],      [ return ((gtkwidgexts_major_version) || (gtkwidgexts_minor_version) || (gtkwidgexts_micro_version)); ],
        [ echo "*** The test program compiled, but did not run. This usually means"
          echo "*** that the run-time linker is not finding GTK_WIDGEXTS or finding the wrong"
          echo "*** version of GTK_WIDGEXTS. If it is not finding GTK_WIDGEXTS, you'll need to set your"
          echo "*** LD_LIBRARY_PATH environment variable, or edit /etc/ld.so.conf to point"
          echo "*** to the installed location  Also, make sure you have run ldconfig if that"
          echo "*** is required on your system"
	  echo "***"
          echo "*** If you have an old version installed, it is best to remove it, although"
          echo "*** you may also be able to get things to work by modifying LD_LIBRARY_PATH"
          echo "***"
          echo "*** If you have a RedHat 5.0 system, you should remove the GTK_WIDGEXTS package that"
          echo "*** came with the system with the command"
          echo "***"
          echo "***    rpm --erase --nodeps gtkwidgexts gtkwidgexts-devel" ],
        [ echo "*** The test program failed to compile or link. See the file config.log for the"
          echo "*** exact error that occured. This usually means GTK_WIDGEXTS was incorrectly installed"
          echo "*** or that you have moved GTK_WIDGEXTS since it was installed. In the latter case, you"
          echo "*** may want to edit the gtkwidgexts-config script: $GTK_WIDGEXTS_CONFIG" ])
          CFLAGS="$ac_save_CFLAGS"
          LIBS="$ac_save_LIBS"
       fi
     fi
     GTK_WIDGEXTS_CFLAGS=""
     GTK_WIDGEXTS_LIBS=""
     ifelse([$3], , :, [$3])
  fi
  AC_SUBST(GTK_WIDGEXTS_CFLAGS)
  AC_SUBST(GTK_WIDGEXTS_LIBS)
  rm -f conf.gtkwidgextstest
])
